Imported from libpng-1.0.8rc1.tar
diff --git a/png.h b/png.h
index 38e017b..aeb86ef 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
 
 /* png.h - header file for PNG reference library
  *
  * libpng version 1.0.8beta4 - July 14, 2000
  * Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -9,7 +9,7 @@
  * Authors and maintainers:
  *  libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *  libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
  *  libpng versions 0.97, January 1998, through 1.0.8beta4 - July 14, 2000: Glenn
  *  See also "Contributing Authors", below.
  *
  * Note about libpng version numbers:
@@ -55,7 +55,8 @@
  *    1.0.7beta11-18                10007  2.1.0.7beta11-18 (binary compatible)
  *    1.0.7rc1-2                    10007  2.1.0.7rc1-2 (binary compatible)
  *    1.0.7                         10007  (still compatible)
- *    1.0.7beta1-2                  10008  2.1.0.8beta1-2
+ *    1.0.8beta1-4                  10008  2.1.0.8beta1-4
+ *    1.0.8rc1                      10008  2.1.0.8rc1
  *
  *    Henceforth the source version will match the shared-library major
  *    and minor numbers; the shared-library major version number will be
@@ -82,7 +83,7 @@
  * If you modify libpng you may insert additional notices immediately following
  * this sentence.
  *
  * libpng version 1.0.8beta4, July 14, 2000, is
  * Copyright (c) 2000 Glenn Randers-Pehrson
  * Distributed according to the same disclaimer and license as libpng-1.0.6
  * with the following individuals added to the list of Contributing Authors
@@ -187,13 +188,13 @@
  * Y2K compliance in libpng:
  * =========================
  *
- *    July 14, 2000
+ *    July 17, 2000
  *
  *    Since the PNG Development group is an ad-hoc body, we can't make
  *    an official declaration.
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
  *    upward through 1.0.8beta4 are Y2K compliant.  It is my belief that earlier
  *    versions were also Y2K compliant.
  *
  *    Libpng only has three year fields.  One is a 2-byte unsigned integer
@@ -249,7 +250,7 @@
  */
 
 /* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.0.8beta4"
+#define PNG_LIBPNG_VER_STRING "1.0.8rc1"
 
 #define PNG_LIBPNG_VER_SONUM   2
 
@@ -259,7 +260,7 @@
 #define PNG_LIBPNG_VER_RELEASE 8
 /* This should match the numeric part of the final component of
  * PNG_LIBPNG_VER_STRING, omitting any leading zero: */
-#define PNG_LIBPNG_VER_BUILD   4
+#define PNG_LIBPNG_VER_BUILD   1
 
 /* Careful here.  At one time, Guy wanted to use 082, but that would be octal.
  * We must not include leading zeros.
@@ -1147,9 +1148,9 @@
 };
 
 /* This prevents a compiler error in png_get_copyright() in png.c if png.c
-and png.h are both at * version 1.0.8beta4
+and png.h are both at * version 1.0.8rc1
  */
-typedef png_structp version_1_0_8beta4;
+typedef png_structp version_1_0_8rc1;
 
 typedef png_struct FAR * FAR * png_structpp;
 
@@ -2131,25 +2132,35 @@
 #if (PNG_DEBUG > 0)
 #if !defined(PNG_DEBUG_FILE) && defined(_MSC_VER)
 #include <crtdbg.h>
-#define png_debug(l,m) if (PNG_DEBUG > l) _RPT0(_CRT_WARN,m)
-#define png_debug1(l,m,p1) if (PNG_DEBUG > l) _RPT1(_CRT_WARN,m,p1)
-#define png_debug2(l,m,p1,p2) if (PNG_DEBUG > l) _RPT2(_CRT_WARN,m,p1,p2)
+#if (PNG_DEBUG > 1)
+#define png_debug(l,m)  _RPT0(_CRT_WARN,m)
+#define png_debug1(l,m,p1)  _RPT1(_CRT_WARN,m,p1)
+#define png_debug2(l,m,p1,p2) _RPT2(_CRT_WARN,m,p1,p2)
+#endif
 #else /* PNG_DEBUG_FILE || !_MSC_VER */
 #ifndef PNG_DEBUG_FILE
 #define PNG_DEBUG_FILE stderr
 #endif /* PNG_DEBUG_FILE */
+#if (PNG_DEBUG > 1)
 #define png_debug(l,m) \
-   if (PNG_DEBUG > l)  \
-     fprintf(PNG_DEBUG_FILE,"%s"m,(l==1 ? "\t" : \
-       (l==2 ? "\t\t":(l>2 ? "\t\t\t":""))))
+{ \
+     int num_tabs=l; \
+     fprintf(PNG_DEBUG_FILE,"%s"m,(num_tabs==1 ? "\t" : \
+       (num_tabs==2 ? "\t\t":(num_tabs>2 ? "\t\t\t":"")))); \
+}
 #define png_debug1(l,m,p1) \
-   if (PNG_DEBUG > l) \
-     fprintf(PNG_DEBUG_FILE,"%s"m,(l==1 ? "\t" : \
-       (l==2 ? "\t\t":(l>2 ? "\t\t\t":""))),p1)
+{ \
+     int num_tabs=l; \
+     fprintf(PNG_DEBUG_FILE,"%s"m,(num_tabs==1 ? "\t" : \
+       (num_tabs==2 ? "\t\t":(num_tabs>2 ? "\t\t\t":""))),p1); \
+}
 #define png_debug2(l,m,p1,p2) \
-   if (PNG_DEBUG > l) \
-     fprintf(PNG_DEBUG_FILE,"%s"m,(l==1 ? "\t" : \
-       (l==2 ? "\t\t":(l>2 ? "\t\t\t":""))),p1,p2)
+{ \
+     int num_tabs=l; \
+     fprintf(PNG_DEBUG_FILE,"%s"m,(num_tabs==1 ? "\t" : \
+       (num_tabs==2 ? "\t\t":(num_tabs>2 ? "\t\t\t":""))),p1,p2); \
+}
+#endif /* (PNG_DEBUG > 1) */
 #endif /* _MSC_VER */
 #endif /* (PNG_DEBUG > 0) */
 #endif /* PNG_DEBUG */
@@ -2171,7 +2182,7 @@
 extern PNG_EXPORT(png_charp,png_get_libpng_ver) PNGARG((png_structp png_ptr));
 
 #define PNG_HEADER_VERSION_STRING \
-   " libpng version 1.0.8beta4 - July 14, 2000 (header)\n"
+   " libpng version 1.0.8rc1 - July 17, 2000 (header)\n"
 
 #ifdef PNG_READ_COMPOSITE_NODIV_SUPPORTED
 /* With these routines we avoid an integer divide, which will be slower on
@@ -1,7 +1,7 @@
 /* png.h - header file for PNG reference library
  *
- * libpng version 1.0.8beta4 - July 14, 2000
+ * libpng version 1.0.8rc1 - July 17, 2000
  * Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -9,7 +9,7 @@
  *  libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *  libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- *  libpng versions 0.97, January 1998, through 1.0.8beta4 - July 14, 2000: Glenn
+ *  libpng versions 0.97, January 1998, through 1.0.8rc1 - July 17, 2000: Glenn
  *  See also "Contributing Authors", below.
  *
@@ -82,7 +83,7 @@
  * this sentence.
  *
- * libpng version 1.0.8beta4, July 14, 2000, is
+ * libpng version 1.0.8rc1, July 17, 2000, is
  * Copyright (c) 2000 Glenn Randers-Pehrson
  * Distributed according to the same disclaimer and license as libpng-1.0.6
@@ -187,13 +188,13 @@
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
- *    upward through 1.0.8beta4 are Y2K compliant.  It is my belief that earlier
+ *    upward through 1.0.8rc1 are Y2K compliant.  It is my belief that earlier
  *    versions were also Y2K compliant.
  *